==> hoogle-5.0.17.11-34-x86_64.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.11
id: hoogle-5.0.17.11-EK3z6OTjgARFIZQB2pZLFg
key: hoogle-5.0.17.11-EK3z6OTjgARFIZQB2pZLFg
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: 135a8550925ebc869e1f6b895c79a543
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.11-EK3z6OTjgARFIZQB2pZLFg
include-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11/include
includes:
    include.h
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0 binary-0.8.6.0
    blaze-html-0.9.1.2-HwoBmHvd8MidwTYIDsO4n
    blaze-markup-0.8.2.3-ATcS0IRQcDMCxhB8vW9N1d bytestring-0.10.8.2
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93
    conduit-extra-1.3.4-GNv58rt6JAeUYsVx1bztm
    connection-0.3.1-3jFFuPxCxgo8iZxzptwf34 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    extra-1.6.18-Hvb5V9crxyzC6wVibsyssz filepath-1.4.2.1
    foundation-0.0.25-L7Ox4wpPmejDhY2IJiYN8j
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3
    http-conduit-2.3.7.3-9kiml6FQ1D94jE9L7wuFp9
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-A2gXX4AHDXW9cGwQMT0Mkv
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    process-extras-0.7.4-H6z2EMu9y4zFwJ7Uv4vmxT
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    storable-tuple-0.0.3.3-6nt4Gdxmd1s9tNdyqMP2Fb
    tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uniplate-1.6.12-JIum57FWZN32cBPgiAnLvS
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-logger-2.3.6-9w7uh45sRSSL1OLn3vwTB0
    warp-3.3.4-Ks8B4cPlDDQG26QixHAf6n
    warp-tls-3.2.8-LUkqkA0AoQeCKKmCJECZb7
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.17.11-35-x86_64.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.11
id: hoogle-5.0.17.11-Bpe6MgQji6o6WuqrRp3EQw
key: hoogle-5.0.17.11-Bpe6MgQji6o6WuqrRp3EQw
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: 6885cfcdb83960e4bc3d60b2d4e5bd5e
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.11-Bpe6MgQji6o6WuqrRp3EQw
include-dirs: /usr/lib/ghc-8.6.5/site-local/hoogle-5.0.17.11/include
includes:
    include.h
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0 binary-0.8.6.0
    blaze-html-0.9.1.2-HwoBmHvd8MidwTYIDsO4n
    blaze-markup-0.8.2.3-ATcS0IRQcDMCxhB8vW9N1d bytestring-0.10.8.2
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93
    conduit-extra-1.3.4-GNv58rt6JAeUYsVx1bztm
    connection-0.3.1-3jFFuPxCxgo8iZxzptwf34 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    extra-1.6.18-Hvb5V9crxyzC6wVibsyssz filepath-1.4.2.1
    foundation-0.0.25-L7Ox4wpPmejDhY2IJiYN8j
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3
    http-conduit-2.3.7.3-FS1jUUT66Fg5QWgfhc60lE
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-8EvF830XPAFBXk2wLGGgWb
    mmap-0.5.9-DPtA2NM6pwvChiGDibkbhO
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    process-extras-0.7.4-H6z2EMu9y4zFwJ7Uv4vmxT
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    storable-tuple-0.0.3.3-6nt4Gdxmd1s9tNdyqMP2Fb
    tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    uniplate-1.6.12-JIum57FWZN32cBPgiAnLvS
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-logger-2.3.6-40OLttPXw39E6RClFS9l7G
    warp-3.3.4-8INcH49wmfRFS0zsa0eyIx
    warp-tls-3.2.8-Ejoow1O5YJ8HQeBJNwaHza
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
